@@ -26,23 +26,20 @@ manipulating such documents.
 
 import decimal
 
-from linaro_json import (json, Schema, Validator)
+from linaro_json.schema import (Schema, Validator)
 from pkg_resources import resource_string
-from versiontools import Version
+import simplejson as json
 
 
-__version__ = Version(1, 1, 1, "final")
+__version__ = (1, 2, 0, "final", 0)
+try:
+    import versiontools
+    __version__ = versiontools.Version.from_tuple(__version__)
+except ImportError:
+    pass
 __all__ = ["get_version", "DocumentIO", "DocumentEvolution", "DocumentFormatError"]
 
 
-def get_version():
-    """
-    Return a string representing the version of linaro_dashboard_bundle
-    package
-    """
-    return str(__version__)
-
-
 class DocumentFormatError(ValueError):
     """
     Exception raised when document format is not in the set of known
@@ -138,6 +135,11 @@ class DocumentIO(object):
                 resource_string(
                     __name__,
                     'schemas/dashboard_bundle_format_1.0.1.json'))),
+        'Dashboard Bundle Format 1.1': Schema(
+            json.loads(
+                resource_string(
+                    __name__,
+                    'schemas/dashboard_bundle_format_1.1.json'))),
     }
 
     @classmethod
@@ -162,7 +164,16 @@ class DocumentIO(object):
                 This method can also raise exceptions raised by
                 DocumentIO.check()
         """
-        doc = json.load(stream, parse_float=decimal.Decimal)
+        doc = json.load(stream, parse_float=decimal.Decimal, object_pairs_hook=json.ordered_dict.OrderedDict)
+        fmt = cls.check(doc)
+        return fmt, doc
+
+    @classmethod
+    def loads(cls, text):
+        """
+        Same as load() but reads data from a string
+        """
+        doc = json.loads(text, parse_float=decimal.Decimal, object_pairs_hook=json.ordered_dict.OrderedDict)
         fmt = cls.check(doc)
         return fmt, doc
 
@@ -184,16 +195,27 @@ class DocumentIO(object):
                 DocumentIO.check()
         """
         cls.check(doc)
-        json.dump(doc, stream, indent=4)
+        json.dump(doc, stream, indent=" " * 2, use_decimal=True)
 
     @classmethod
-    def loads(cls, text):
+    def dumps(cls, doc):
         """
-        Same as load() but reads data from a string
+        Check and save a JSON document as string
+
+        :Discussion:
+            The document is validated against a set of known formats and
+            schemas and saved to a string
+
+        :Return value:
+            JSON document as string
+
+        :Exceptions:
+            Other exceptions
+                This method can also raise exceptions raised by
+                DocumentIO.check()
         """
-        doc = json.loads(text, parse_float=decimal.Decimal)
-        fmt = cls.check(doc)
-        return fmt, doc
+        cls.check(doc)
+        return json.dumps(doc, indent=" " * 2, use_decimal=True)
 
     @classmethod
     def check(cls, doc):
